@@ -8,6 +8,7 @@ import time
 import types
 import typing
 import warnings
+from typing import Dict
 
 import cloudpickle
 import fabric
@@ -130,11 +131,18 @@ class WandbWrapper:
             register_param(k, v)
 
     def add_scalar(self, tag: str, scalar_value: float, global_step: int):
+        if scalar_value != scalar_value:
+            warnings.warn(f"{tag} is {scalar_value} at {global_step} :(")
+
         scalar_value = float(scalar_value)  # silently remove extra data such as torch gradients
         self.run.log({tag: scalar_value}, step=global_step, commit=False)
         if self.tensorboard:
             self.tensorboard.add_scalar(tag, scalar_value, global_step=global_step)
 
+    def add_scalars(self, scalars: Dict[str, float], global_step: int):
+        for k, v in scalars.items():
+            self.add_scalar(k, v, global_step)
+
     def add_figure(self, tag, figure, global_step, close=True):
         self.run.log({tag: figure}, global_step)
         if close:
@@ -145,6 +153,9 @@ class WandbWrapper:
 
     @staticmethod
     def add_histogram(tag, values, global_step):
+        if len(values) <= 2:
+            raise ValueError("histogram requires at least 3 values")
+
         if isinstance(values, (tuple, list)) and len(values) == 2:
             wandb.log({tag: wandb.Histogram(np_histogram=values)}, step=global_step, commit=False)
         else:
@@ -226,6 +237,7 @@ def deploy(host: str = "", sweep_yaml: str = "", proc_num: int = 1, wandb_kwargs
         tb_dir = os.path.join(git_repo.working_dir, ARTIFACTS_PATH, "tensorboard/", experiment_id, dtm)
         logger = WandbWrapper(f"{experiment_id}_{dtm}", local_tensorboard=_setup_tb(logdir=tb_dir), **common_kwargs)
     else:
+        ensure_torch_compatibility()
         experiment_id = _ask_experiment_id(host, sweep_yaml)
         print(f"experiment_id: {experiment_id}")
         if local_run:
@@ -238,6 +250,15 @@ def deploy(host: str = "", sweep_yaml: str = "", proc_num: int = 1, wandb_kwargs
     return logger
 
 
+def ensure_torch_compatibility():
+    with open("requirements.txt") as fin:
+        reqs = fin.read()
+        # torch, vision or audio.
+        if "torch" not in reqs and "torch==1.7.1+cu110" not in reqs:
+            # https://mila-umontreal.slack.com/archives/CFAS8455H/p1624292393273100?thread_ts=1624290747.269100&cid=CFAS8455H
+            warnings.warn("""torch rocm4.2 version will be installed on the cluster which is not supported specify torch==1.7.1+cu110 in requirements.txt instead""")
+
+
 def _ask_experiment_id(cluster, sweep):
     title = f'{"[CLUSTER" if cluster else "[LOCAL"}'
     if sweep:
